from setuptools import setup

setup(name='mengheng_probability',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['mengheng_probability'],
      author='Mengheng Xue',
      author_email='mx586@nyu.edu',
      zip_safe=False)
